@@ -13,10 +13,9 @@ CHECKOUT_PATH = os.path.dirname(os.path.realpath(__file__))
 CHECKOUT_GYP_PATH = os.path.join(CHECKOUT_PATH, "gyp")
 
 parser = argparse.ArgumentParser()
-parser.add_argument("--no-commit",
-    action="store_true",
-    dest="no_commit",
-    help="do not run git-commit")
+parser.add_argument(
+    "--no-commit", action="store_true", dest="no_commit", help="do not run git-commit"
+)
 parser.add_argument("tag", help="gyp tag to update to")
 args = parser.parse_args()
 
@@ -37,8 +36,8 @@ with tempfile.TemporaryDirectory() as tmp_dir:
 
         print("Unzipping...")
         with tarfile.open(tar_file, "r:gz") as tar_ref:
-            def is_within_directory(directory, target):
 
+            def is_within_directory(directory, target):
                 abs_directory = os.path.abspath(directory)
                 abs_target = os.path.abspath(target)
 
@@ -47,7 +46,6 @@ with tempfile.TemporaryDirectory() as tmp_dir:
                 return prefix == abs_directory
 
             def safe_extract(tar, path=".", members=None, *, numeric_owner=False):
-
                 for member in tar.getmembers():
                     member_path = os.path.join(path, member.name)
                     if not is_within_directory(path, member_path):
@@ -65,7 +63,7 @@ with tempfile.TemporaryDirectory() as tmp_dir:
         )
 
 if not args.no_commit:
-  subprocess.check_output(["git", "add", "gyp"], cwd=CHECKOUT_PATH)
-  subprocess.check_output([
-    "git", "commit", "-m", f"feat(gyp): update gyp to {args.tag}"
-  ])
+    subprocess.check_output(["git", "add", "gyp"], cwd=CHECKOUT_PATH)
+    subprocess.check_output(
+        ["git", "commit", "-m", f"feat(gyp): update gyp to {args.tag}"]
+    )
